<?php
/**
 * @package         FireBox
 * @version         1.0.9 Free
 * 
 * @author          FirePlugins <info@fireplugins.com>
 * @link            https://www.fireplugins.com
 * @copyright       Copyright © 2021 FirePlugins All Rights Reserved
 * @license         GNU GPLv3 <http://www.gnu.org/licenses/gpl.html> or later
*/

namespace FireBox\Core\Admin\Forms\FireBox;

if (!defined('ABSPATH'))
{
	exit; // Exit if accessed directly.
}

use FireBox\Core\Helpers\BoxHelper;

class Assignments
{
	/**
	 * Holds the Publishing Assignments Settings
	 * 
	 * @return  array
	 */
	public function getSettings()
	{
		$settings = [
			'title' => 'FPF_PUBLISHING_RULES',
			'content' => [
				// Mirror Box
				'mirror_box' => [
					'wrapper' => [
						'class' => ['grid-x', 'grid-margin-x', 'grid-margin-y']
					],
					'fields' => [
						[
							'name' => 'mirror',
							'type' => 'FPToggle',
							'label' => 'FB_METABOX_PA_MIRROR_DISPLAY',
							'description' => 'FB_METABOX_PA_MIRROR_DISPLAY_DESC',
							'input_class' => ['yesno'],
							'class' => ['large-auto']
						],
						[
							'name' => 'mirror_box',
							'type' => 'Dropdown',
							'label' => 'FB_POPUP',
							'description' => 'FB_ASSIGNMENTS_POPUP_SELECT_DESC',
							'default' => 1,
							'input_class' => ['medium'],
							'choices' => BoxHelper::getAllMirrorBoxesExceptID(get_the_ID()),
							'showon' => '[mirror]:1'
						],
						[
							'name' => 'assignmentMatchingMethod',
							'type' => 'Toggle',
							'label' => 'FB_METABOX_PA_MATCHING_METHOD',
							'description' => 'FB_METABOX_PA_MATCHING_METHOD_DESC',
							'default' => 'and',
							'choices' => [
								'and' => 'FPF_ALL',
								'or' => 'FPF_ANY'
							],
							'showon' => '[mirror]:0',
							'class' => ['large-auto']
						]
					]
				],
				// Menu Item
				'menu_item' => [
					'wrapper' => ['showon' => '[mirror]:0'],
					'title' => [
						'title' => 'FB_METABOX_PA_PAGE_URL',
						'description' => 'FB_METABOX_PA_PAGE_URL_DESC'
					],
					'fields' => [
						[
							'type' => 'AssignmentSelection',
							'name' => 'assignments.assign_menu.selection',
							'label' => 'FPF_PA_MENU_ITEM_AS',
							'description' => 'FPF_PA_MENU_ITEM_AS_DESC',
							'input_class' => ['disabled-yes-no']
						],
						[
							'type' => 'SearchDropdown',
							'name' => 'assignments.assign_menu.list',
							'path' => '\FPFramework\Helpers\MenuHelper',
							'placeholder' => 'FPF_PA_MENU_ITEM_HINT',
							'label' => 'FPF_SELECTION',
							'description' => 'FPF_PA_PAGE_URL_AS_DESC',
							'items' => fpframework()->helper->menu->getItems(),
							'lazyload' => true,
							'showon' => '[assignments][assign_menu][selection]:1,2'
						],
						[
							'name' => 'assignments.assign_menu.param_inc_children',
							'type' => 'Toggle',
							'label' => 'FPF_PA_ASSIGN_MENU_CHILD',
							'description' => 'FPF_PA_ASSIGN_MENU_CHILD_DESC',
							'default' => 0,
							'choices' => [
								0 => 'FPF_NO',
								1 => 'FPF_YES',
								2 => 'FPF_ONLY'
							],
							'showon' => '[assignments][assign_menu][selection]:1,2'
						],
						// URL
						[
							'type' => 'AssignmentSelection',
							'name' => 'assignments.assign_url.selection',
							'label' => 'FPF_URL',
							'description' => 'FPF_PA_URL_DESC',
							'input_class' => ['disabled-yes-no'],
							'class' => ['border-top']
						],
						[
							'type' => 'Textarea',
							'name' => 'assignments.assign_url.list',
							'rows' => 10,
							'filter' => 'textarea',
							'input_class' => ['fullwidth'],
							'placeholder' => '/blog/welcome-to-our-site',
							'label' => 'FPF_PA_URL_MATCHES',
							'description' => 'FPF_PA_URL_MATCHES_DESC',
							'showon' => '[assignments][assign_url][selection]:1,2'
						],
						[
							'name' => 'assignments.assign_url.param_regex',
							'type' => 'FPToggle',
							'label' => 'FPF_PA_REGUAL_EXPRESSION',
							'description' => 'FPF_PA_REGUAL_EXPRESSION_DESC',
							'default' => '0',
							'showon' => '[assignments][assign_url][selection]:1,2'
						]
					]
				],
				// Datetime
				'datetime' => [
					'wrapper' => ['showon' => '[mirror]:0'],
					'title' => [
						'title' => 'FB_METABOX_PA_DATETIME',
						'description' => 'FB_METABOX_PA_DATETIME_DESC'
					],
					'fields' => [
						
						// Timerange
						
						
						[
							'type' => 'Pro',
							'label' => 'FPF_PA_DATETIME',
							'description' => 'FPF_PA_DATETIME_DESC'
						],
						[
							'type' => 'Pro',
							'label' => 'FPF_PA_TIMERANGE',
							'description' => 'FPF_PA_TIMERANGE_DESC'
						],
						
					]
				],
				// WordPress User Visitor
				'wordpress_user_visitor' => [
					'wrapper' => ['showon' => '[mirror]:0'],
					'title' => [
						'title' => 'FB_METABOX_PA_USER_VISITOR',
						'description' => 'FB_METABOX_PA_USER_VISITOR_DESC'
					],
					'fields' => [
						
						// Viewed Another Box
						
						// Time on Site
						
						
						[
							'type' => 'Pro',
							'label' => 'FPF_USER_ROLE',
							'description' => 'FPF_USER_ROLE_DESC'
						],
						[
							'type' => 'Pro',
							'label' => 'FPF_USER_ID',
							'description' => 'FPF_USER_ID_DESC'
						],
						[
							'type' => 'Pro',
							'label' => 'FPF_NUMBER_PAGEVIEWS',
							'description' => 'FPF_NUMBER_PAGEVIEWS_DESC'
						],
						[
							'type' => 'Pro',
							'label' => 'FB_VIEWED_ANOTHER_BOX',
							'description' => 'FB_VIEWED_ANOTHER_BOX_DESC'
						],
						[
							'type' => 'Pro',
							'label' => 'FPF_TIMEONSITE',
							'description' => 'FPF_TIMEONSITE_DESC'
						]
						
					]
				],
				// WordPress Content
				'wordpress_content' => [
					'wrapper' => ['showon' => '[mirror]:0'],
					'title' => [
						'title' => 'FPF_WORDPRESS_CONTENT',
						'description' => 'FPF_WORDPRESS_CONTENT_DESC'
					],
					'fields' => [
						// Posts
						[
							'type' => 'AssignmentSelection',
							'name' => 'assignments.assign_posts.selection',
							'label' => 'FPF_POST',
							'description' => 'FPF_PA_POSTS_DESC',
							'input_class' => ['disabled-yes-no']
						],
						[
							'type' => 'SearchDropdown',
							'name' => 'assignments.assign_posts.list',
							'path' => '\FPFramework\Helpers\PostsHelper',
							'placeholder' => 'FPF_PA_POSTS_HINT',
							'label' => 'FPF_SELECTION',
							'description' => 'FB_PA_POSTS_AS_DESC',
							'items' => fpframework()->helper->posts->getItems(),
							'lazyload' => true,
							'showon' => '[assignments][assign_posts][selection]:1,2'
						],
						// Pages
						[
							'type' => 'AssignmentSelection',
							'name' => 'assignments.assign_pages.selection',
							'label' => 'FPF_PAGE',
							'description' => 'FPF_PA_PAGES_DESC',
							'input_class' => ['disabled-yes-no'],
							'class' => ['border-top']
						],
						[
							'type' => 'SearchDropdown',
							'name' => 'assignments.assign_pages.list',
							'path' => '\FPFramework\Helpers\PagesHelper',
							'placeholder' => 'FPF_PA_PAGES_HINT',
							'label' => 'FPF_SELECTION',
							'description' => 'FB_PA_PAGES_AS_DESC',
							'items' => fpframework()->helper->pages->getItems(),
							'lazyload' => true,
							'showon' => '[assignments][assign_pages][selection]:1,2'
						],
						// Custom Post Types
						
						// Tags
						
						// Categories
						
						
						[
							'type' => 'Pro',
							'label' => 'FPF_CPTS',
							'description' => 'FPF_PA_CPTS_DESC'
						],
						[
							'type' => 'Pro',
							'label' => 'FPF_TAGS',
							'description' => 'FPF_PA_TAGS_DESC'
						],
						[
							'type' => 'Pro',
							'label' => 'FPF_CATEGORIES',
							'description' => 'FPF_PA_POST_CATEGORIES_DESC'
						]
						
					]
				],
				// Visitor Platform
				'visitor_platform' => [
					'wrapper' => ['showon' => '[mirror]:0'],
					'title' => [
						'title' => 'FPF_METABOX_PA_VISITOR_PLATFORM',
						'description' => 'FPF_METABOX_PA_VISITOR_PLATFORM_DESC'
					],
					'fields' => [
						// Device
						
						// Browser
						
						// OS
						
						
						[
							'type' => 'Pro',
							'label' => 'FPF_DEVICE',
							'description' => 'FPF_PA_DEVICE_DESC'
						],
						[
							'type' => 'Pro',
							'label' => 'FPF_BROWSER',
							'description' => 'FPF_PA_BROWSER_DESC'
						],
						[
							'type' => 'Pro',
							'label' => 'FPF_OS',
							'description' => 'FPF_PA_OS_DESC'
						]
						
					]
				],
				// Geolocating
				'geolocating' => [
					'wrapper' => ['showon' => '[mirror]:0'],
					'title' => [
						'title' => 'FPF_PA_GEOLOCATING',
						'description' => 'FPF_PA_GEOLOCATING_DESC'
					],
					'fields' => [
						
						// Continent
						
						// IP Address
						
						
						[
							'type' => 'Pro',
							'label' => 'FPF_COUNTRY',
							'description' => 'FPF_COUNTRY_DESC'
						],
						[
							'type' => 'Pro',
							'label' => 'FPF_CONTINENT',
							'description' => 'FPF_CONTINENT_DESC'
						],
						[
							'type' => 'Pro',
							'label' => 'FPF_IP_ADDRESS',
							'description' => 'FPF_IP_ADDRESS_DESC'
						]
						
					]
				],
				// System Integrations
				'system_integrations' => $this->getSystemIntegrations(),
				// Advanced
				'advanced' => [
					'wrapper' => ['showon' => '[mirror]:0'],
					'title' => [
						'title' => 'FPF_ADVANCED',
					],
					'fields' => [
						// Referrer URL
						
						// Cookie
						
						// PHP
						
						
						[
							'type' => 'Pro',
							'label' => 'FPF_REFERRER_URL',
							'description' => 'FPF_REFERRER_URL_DESC'
						],
						[
							'type' => 'Pro',
							'label' => 'FPF_COOKIE',
							'description' => 'FPF_PA_COOKIE_DESC'
						],
						[
							'type' => 'Pro',
							'label' => 'FPF_PHP',
							'description' => 'FPF_PHP_DESC'
						]
						
					]
				]
			]
		];

		return apply_filters('firebox/box/settings/assignments/edit', $settings);
	}

	/**
	 * Holds the System Integrations Settings
	 * 
	 * @return  array
	 */
	private function getSystemIntegrations()
	{
		$settings = [];

		$settings = apply_filters('firebox/metabox/fb/si_settings_filter', $settings);

		if (empty($settings))
		{
			return [];
		}

		$data = [
			'wrapper' => ['showon' => '[mirror]:0'],
			'title' => [
				'name' => 'heading_system_integrations',
				'title' => 'FB_METABOX_SYSTEM_INTEGRATIONS',
				'description' => 'FB_METABOX_SYSTEM_INTEGRATIONS_DESC',
			],
			'fields' => $settings
		];

		return $data;
	}
}