<?php
/**
 * @package         FirePlugins Framework
 * @version         1.0.20
 * 
 * @author          FirePlugins <info@fireplugins.com>
 * @link            https://www.fireplugins.com
 * @copyright       Copyright © 2021 FirePlugins All Rights Reserved
 * @license         GNU GPLv3 <http://www.gnu.org/licenses/gpl.html> or later
*/

namespace FPFramework\Base\Assignments;

if (!defined('ABSPATH'))
{
	exit; // Exit if accessed directly.
}

use FPFramework\Base\Assignment;

/**
 *  IP addresses sample
 *
 *  Greece / Dodecanese:  94.67.238.3
 *  Belgium / Flanders:   37.62.255.255
 *  USA / New York:       72.229.28.185
 */
class Geoipbase extends Assignment
{
    /**
     *  GeoIP Class
     *
     *  @var  class
     */
    protected $geo;

    /**
     *  Class constructor
     *
     *  @param  object  $assignment
     *  @param  object  $factory
     */
    public function __construct($assignment, $factory)
    {
        parent::__construct($assignment, $factory);

        // Load Geo Class
        $ip = isset($assignment->params->ip) ? $assignment->params->ip : null;
        $this->loadGeo($ip);

        if (!$this->geo)
        {
            return false;
        }

        // Convert a comma/newline separated selection string into an array
        if (!is_array($this->selection))
        {
            $this->selection = $this->splitKeywords($this->selection);
        }
    }

    /**
     *  Load GeoIP Classes
     *
     *  @return  void
     */
    private function loadGeo($ip = null)
    {
        $this->geo = $this->factory->getGeoIP($ip);
    }
}
